// Mediator: user.component.ts

import { Component } from '@angular/core';
import { User, UserService } from './user.service';

@Component({
    selector: 'app-user',
    template: './user.component.html',
})
export class UserComponent {
    user$: Observable<User>;
    name: string;
    age: number;
    ageColorChecker: AgeColorChecker;
    ageChangeChecker: AgeChangeChecker;

    constructor(private userService: UserService) {
        this.user = this.userService.getUser();
    }

    onNameInputChange(event: Event) {
        this.name = event.target as HTMLInputElement;
    }

    onAgeInputChange(event: Event) {
        this.age = event.target as HTMLInputElement;
    }

    getColorByAge(age: number): string {
        if (age >= 65) {
            return "#FF0000";
        } else {
            return "#00FF00";
        }
    }

    submit(): void {
        this.userService.createUser(this.name, this.age);
    }
}

// Controller for coloring

export class AgeColorChecker {
    public static getColorByAge(age: number): string {
        if (age >= 65) {
            return "#FF0000";
        } else {
            return "#00FF00";
        }
    }
}

// Controller for text writing

export class AgeChangeChecker {
    public static checkAgeChange(oldAge: number, newAge: number): string {
        if (!newAge) {
            return "same";
        }
        if (oldAge > newAge) {
            return "lower";
        } else if (newAge > oldAge) {
            return "higher";
        }
        return "same";
    }
}