// Controller: user.component.ts

import { Component } from '@angular/core';
import { User, UserService } from './user.service';

@Component({
    selector: 'app-user',
    template: './user.component.html',
})
export class UserComponent {
    user: User;
    name: string;
    age: number;
    ageColor: string;
    ageChange: string;

    constructor(private userService: UserService) {
        this.userService.getUser().subscribe(user => {
            this.user = user;
            this.ageColor = getColorByAge(this.user.age);
            this.ageChange = checkAgeChange(this.user.age, this.age);
        });
    }

    getColorByAge(age: number): string {
        if (age >= 65) {
            return "#FF0000";
        } else {
            return "#00FF00";
        }
    }

    checkAgeChange(oldAge: number, newAge: number): string {
        if (!newAge) {
            return "same";
        }
        if (oldAge > newAge) {
            return "lower";
        } else if (newAge > oldAge) {
            return "higher";
        }
        return "same";
    }

    submit(): void {
        this.userService.createUser(this.name, this.age);
    }
}