// Presenter: user.component.ts

import { Component, ElementRef, ViewChild, AfterViewInit } from '@angular/core';
import { User, UserService } from './user.service';
import { FormGroup, FormControl, Validators } from '@angular/forms';

@Component({
    selector: 'app-user',
    template: './user.component.html',
})
export class UserComponent implements AfterViewInit {
    user: User;
    form: FormGroup;

    @ViewChild('userName', { static: false }) userName: ElementRef;
    @ViewChild('userAge', { static: false }) userAge: ElementRef;

    constructor(private userService: UserService) { }

    ngAfterViewInit() {
        this.userService.getUser().subscribe(user => {
            this.user = user;
            this.updateView(this.user);
        });
        this.form = new FormGroup({
            name: new FormControl('', Validators.required),
            age: new FormControl('', [Validators.required, Validators.min(1)])
        });
    }

    updateView(user: User) {
        this.userName.nativeElement.textContent = `Name: ${user.name}`;
        this.userAge.nativeElement.textContent = `Age: ${user.age}`;
    }

    submit(): void {
        if (this.form.valid) {
            this.userService.createUser((this.form.value) as User);
        }
    }
}